pub struct GnuplotAxis { /* private fields */ }Expand description
For labeling the gnuplot plots axis
Implementations
Sourceimpl GnuplotAxis
impl GnuplotAxis
Sourcepub fn set_rotation(&mut self, rotation_degrees: f32)
pub fn set_rotation(&mut self, rotation_degrees: f32)
Set the rotation value. Tics will be displayed rotated to the right by the requested amount
Sourcepub fn from_labels(labels: Vec<String>) -> Self
pub fn from_labels(labels: Vec<String>) -> Self
Create new GnuplotAxis::Labels
- Vector contains labels used for axis
Sourcepub fn from_slice(labels: &[&str]) -> Self
pub fn from_slice(labels: &[&str]) -> Self
Similar to from_labels
- Slice of slice is converted to Vector of Strings and
Self::from_labels(vec)is called