Module bootstrap

Module bootstrap 

Bootstrap resampling functions

Functions

bootstrap
returns reduced value + variance (estimated error is sqrt of variance) Note, that you can use bootstrap_copyable if your N1 implements Copy
bootstrap_copyable
Similar to bootstrap but for stuff that implements Copy. Likely more efficient in these cases returns reduced value + variance (estimated error is sqrt of variance)